@@ -1,7 +1,3 @@
-import numpy as np
-from numbers import Number
-
-
 def isnumber(value):
     """Check if the target value is a number.
 
@@ -13,11 +9,11 @@ def isnumber(value):
     """
 
     # Note boolean can be converted to number so it has to be avoided
-    if type(value) is bool:
+    if isinstance(value, bool):
         return False
 
     try:
         float(value)
         return True
-    except:
+    except ValueError:
         return False
